<?php

use CKPL\Pay\Storage\StorageInterface;

require_once 'library/internals/autoload.php';

/**
 * Plugin Name: WooCommerce Conotoxia Pay Gateway
 * Description: Conotoxia Pay payment gateway for WooCommerce
 * Version: 0.1.0
 * Author: Cinkciarz.pl Sp. z o.o.
 * Author URI: http://cinkciarz.pl
 * License: MIT
 * Text Domain: conotoxia-pay
 * Domain Path: /lang
 */

add_action('plugins_loaded', 'woocommerce_conotoxia_pay_init', 0);

register_activation_hook(__FILE__, 'woocommerce_conotoxia_pay_install');
register_deactivation_hook(__FILE__, 'woocommerce_conotoxia_pay_uninstall');

function woocommerce_conotoxia_pay_init()
{
    if (!class_exists('WC_Payment_Gateway')) {
        return;
    }

    load_plugin_textdomain('conotoxia-pay', false, dirname(plugin_basename(__FILE__)) . '/lang/');

    include_once('includes/class-woocommerce-conotoxia-pay-utils.php');
    include_once('includes/class-woocommerce-conotoxia-pay-storage.php');
    include_once('includes/class-woocommerce-conotoxia-pay.php');

    add_filter('woocommerce_payment_gateways', 'woocommerce_conotoxia_pay_add_gateway');
}

function woocommerce_conotoxia_pay_add_gateway($methods)
{
    $methods[] = 'WC_Gateway_Conotoxia_Pay';

    return $methods;
}

function woocommerce_conotoxia_pay_install()
{
    add_option( 'conotoxia-pay-version', '0.1.0');
    add_option( 'conotoxia-pay-' . StorageInterface::TOKEN, '');
    add_option( 'conotoxia-pay-' . StorageInterface::PAYMENT_SERVICE_PUBLIC_KEYS, '');
    add_option( 'conotoxia-pay-' . StorageInterface::PUBLIC_KEY_ID, '');
    add_option( 'conotoxia-pay-' . StorageInterface::PUBLIC_KEY_CHECKSUM, '');
}


function woocommerce_conotoxia_pay_uninstall()
{
    delete_option( 'conotoxia-pay-version');
    delete_option( 'conotoxia-pay-' . StorageInterface::TOKEN);
    delete_option( 'conotoxia-pay-' . StorageInterface::PAYMENT_SERVICE_PUBLIC_KEYS);
    delete_option( 'conotoxia-pay-' . StorageInterface::PUBLIC_KEY_ID);
    delete_option( 'conotoxia-pay-' . StorageInterface::PUBLIC_KEY_CHECKSUM);
}
